# FulHash Schemas (v1.0.0)

- `digest.schema.json` – canonical JSON payload returned by FulHash helpers when computing digests (algorithm + hex + optional formatted/bytes fields).
- `checksum-string.schema.json` – canonical checksum string format `<algorithm>:<hex>` used for metadata fields (e.g., Pathfinder checksums).

These schemas validate assets generated by FulHash implementations in all Fulmen helper libraries.
